# e4l

## Motivation

This is [enum4linux-ng]() but you can install it via pip, because this h4x0rish installations suck.

## Installation

```
pip install e4l
```

## License

This project is licensed under the GPL-3 license.
